==> ejc-dxcheck-impl-3.0.0-20240614.083049-58-sources.jar: com/ejianc/business/dxcheck/model/vo/TeamVO.java <==
package com.ejianc.business.dxcheck.model.vo;/*author Wyx*/

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;
import java.util.List;

public class TeamVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Integer serialNum;//序号
    private String assessmentUnitCode;//考核单/部门Code
    private String assessmentUnitName;//考核单位/部门名称
    private String assessorJobNum;//考核人员工号
    private String assessorName;//考核人员
    private String leaderInfoDepartmentName;//信息化部门领导
    private String leaderInfoDepartmentNum;//信息化部门领导工号
    private String leaderProjectManagementName;//项目分管领导
    private String leaderProjectManagementNum;//项目分管领导工号
    private String leaderUnitResponseNum;//单位负责人领导工号
    private String leaderUnitResponseName;//单位负责领导
    private String modifierJobNum;//修改人工号
    private String modifierName;//修改人
    private int teamType; //组类型
    private String teamName;//考评组名称
    private String TeamDescribe;//描述

    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }

    public String getTeamDescribe() {
        return TeamDescribe;
    }

    public void setTeamDescribe(String teamDescribe) {
        TeamDescribe = teamDescribe;
    }

    private List<TeamUserVO> teamUserList;//组成员

    public List<TeamUserVO> getTeamUserList() {
        return teamUserList;
    }

    public void setTeamUserList(List<TeamUserVO> teamUserList) {
        this.teamUserList = teamUserList;
    }

    public int getTeamType() {
        return teamType;
    }

    public void setTeamType(int teamType) {
        this.teamType = teamType;
    }

    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date modifyTime;//修改人修改时间

    public Integer getSerialNum() {
        return serialNum;
    }

    public void setSerialNum(Integer serialNum) {
        this.serialNum = serialNum;
    }

    public String getAssessmentUnitCode() {
        return assessmentUnitCode;
    }

    public void setAssessmentUnitCode(String assessmentUnitCode) {
        this.assessmentUnitCode = assessmentUnitCode;
    }

    public String getAssessmentUnitName() {
        return assessmentUnitName;
    }

    public void setAssessmentUnitName(String assessmentUnitName) {
        this.assessmentUnitName = assessmentUnitName;
    }

    public String getAssessorJobNum() {
        return assessorJobNum;
    }

    public void setAssessorJobNum(String assessorJobNum) {
        this.assessorJobNum = assessorJobNum;
    }

    public String getAssessorName() {
        return assessorName;
    }

    public void setAssessorName(String assessorName) {
        this.assessorName = assessorName;
    }

    public String getLeaderInfoDepartmentName() {
        return leaderInfoDepartmentName;
    }

    public void setLeaderInfoDepartmentName(String leaderInfoDepartmentName) {
        this.leaderInfoDepartmentName = leaderInfoDepartmentName;
    }

    public String getLeaderInfoDepartmentNum() {
        return leaderInfoDepartmentNum;
    }

    public void setLeaderInfoDepartmentNum(String leaderInfoDepartmentNum) {
        this.leaderInfoDepartmentNum = leaderInfoDepartmentNum;
    }

    public String getLeaderProjectManagementName() {
        return leaderProjectManagementName;
    }

    public void setLeaderProjectManagementName(String leaderProjectManagementName) {
        this.leaderProjectManagementName = leaderProjectManagementName;
    }

    public String getLeaderProjectManagementNum() {
        return leaderProjectManagementNum;
    }

    public void setLeaderProjectManagementNum(String leaderProjectManagementNum) {
        this.leaderProjectManagementNum = leaderProjectManagementNum;
    }

    public String getLeaderUnitResponseNum() {
        return leaderUnitResponseNum;
    }

    public void setLeaderUnitResponseNum(String leaderUnitResponseNum) {
        this.leaderUnitResponseNum = leaderUnitResponseNum;
    }

    public String getLeaderUnitResponseName() {
        return leaderUnitResponseName;
    }

    public void setLeaderUnitResponseName(String leaderUnitResponseName) {
        this.leaderUnitResponseName = leaderUnitResponseName;
    }

    public String getModifierJobNum() {
        return modifierJobNum;
    }

    public void setModifierJobNum(String modifierJobNum) {
        this.modifierJobNum = modifierJobNum;
    }

    public String getModifierName() {
        return modifierName;
    }

    public void setModifierName(String modifierName) {
        this.modifierName = modifierName;
    }

    public Date getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(Date modifyTime) {
        this.modifyTime = modifyTime;
    }
}

==> ejc-dxcheck-impl-3.0.0-20240622.090556-81-sources.jar: com/ejianc/business/dxcheck/model/vo/TeamVO.java <==
package com.ejianc.business.dxcheck.model.vo;/*author Wyx*/

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;
import java.util.List;

public class TeamVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Integer serialNum;//序号
    private String assessmentUnitCode;//考核单/部门Code
    private String assessmentUnitName;//考核单位/部门名称
    private String assessorJobNum;//考核人员工号
    private String assessorName;//考核人员
    private String leaderInfoDepartmentName;//信息化部门领导
    private String leaderInfoDepartmentNum;//信息化部门领导工号
    private String leaderProjectManagementName;//项目分管领导
    private String leaderProjectManagementNum;//项目分管领导工号
    private String leaderUnitResponseNum;//单位负责人领导工号
    private String leaderUnitResponseName;//单位负责领导
    private String modifierJobNum;//修改人工号
    private String modifierName;//修改人
    private int teamType; //组类型
    private String teamName;//考评组名称
    private String TeamDescribe;//描述

   private String teamUsersId;

    public String getTeamUsersId() {
        return teamUsersId;
    }

    public void setTeamUsersId(String teamUsersId) {
        this.teamUsersId = teamUsersId;
    }

    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }

    public String getTeamDescribe() {
        return TeamDescribe;
    }

    public void setTeamDescribe(String teamDescribe) {
        TeamDescribe = teamDescribe;
    }

    private List<TeamUserVO> teamUserList;//组成员

    public List<TeamUserVO> getTeamUserList() {
        return teamUserList;
    }

    public void setTeamUserList(List<TeamUserVO> teamUserList) {
        this.teamUserList = teamUserList;
    }

    public int getTeamType() {
        return teamType;
    }

    public void setTeamType(int teamType) {
        this.teamType = teamType;
    }

    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date modifyTime;//修改人修改时间

    public Integer getSerialNum() {
        return serialNum;
    }

    public void setSerialNum(Integer serialNum) {
        this.serialNum = serialNum;
    }

    public String getAssessmentUnitCode() {
        return assessmentUnitCode;
    }

    public void setAssessmentUnitCode(String assessmentUnitCode) {
        this.assessmentUnitCode = assessmentUnitCode;
    }

    public String getAssessmentUnitName() {
        return assessmentUnitName;
    }

    public void setAssessmentUnitName(String assessmentUnitName) {
        this.assessmentUnitName = assessmentUnitName;
    }

    public String getAssessorJobNum() {
        return assessorJobNum;
    }

    public void setAssessorJobNum(String assessorJobNum) {
        this.assessorJobNum = assessorJobNum;
    }

    public String getAssessorName() {
        return assessorName;
    }

    public void setAssessorName(String assessorName) {
        this.assessorName = assessorName;
    }

    public String getLeaderInfoDepartmentName() {
        return leaderInfoDepartmentName;
    }

    public void setLeaderInfoDepartmentName(String leaderInfoDepartmentName) {
        this.leaderInfoDepartmentName = leaderInfoDepartmentName;
    }

    public String getLeaderInfoDepartmentNum() {
        return leaderInfoDepartmentNum;
    }

    public void setLeaderInfoDepartmentNum(String leaderInfoDepartmentNum) {
        this.leaderInfoDepartmentNum = leaderInfoDepartmentNum;
    }

    public String getLeaderProjectManagementName() {
        return leaderProjectManagementName;
    }

    public void setLeaderProjectManagementName(String leaderProjectManagementName) {
        this.leaderProjectManagementName = leaderProjectManagementName;
    }

    public String getLeaderProjectManagementNum() {
        return leaderProjectManagementNum;
    }

    public void setLeaderProjectManagementNum(String leaderProjectManagementNum) {
        this.leaderProjectManagementNum = leaderProjectManagementNum;
    }

    public String getLeaderUnitResponseNum() {
        return leaderUnitResponseNum;
    }

    public void setLeaderUnitResponseNum(String leaderUnitResponseNum) {
        this.leaderUnitResponseNum = leaderUnitResponseNum;
    }

    public String getLeaderUnitResponseName() {
        return leaderUnitResponseName;
    }

    public void setLeaderUnitResponseName(String leaderUnitResponseName) {
        this.leaderUnitResponseName = leaderUnitResponseName;
    }

    public String getModifierJobNum() {
        return modifierJobNum;
    }

    public void setModifierJobNum(String modifierJobNum) {
        this.modifierJobNum = modifierJobNum;
    }

    public String getModifierName() {
        return modifierName;
    }

    public void setModifierName(String modifierName) {
        this.modifierName = modifierName;
    }

    public Date getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(Date modifyTime) {
        this.modifyTime = modifyTime;
    }
}
